@@ -9,9 +9,10 @@
 
 import pilas
 from pilas.actores import Texto
+from pilas import colores
 
 class Temporizador(Texto):
-    def __init__(self, x=0, y=0, color=pilas.colores.negro):
+    def __init__(self, x=0, y=0, color=colores.negro):
         Texto.__init__(self, '0', x=x, y=y)
         self.ajustar(1, self.funcion_vacia)
         self.color = color
@@ -51,8 +52,8 @@ class Temporizador(Texto):
 
     # iniciamos temporizador con respectivas funciones y tiempo ajustado
     def iniciar(self):
-        pilas.mundo.agregar_tarea(self.tiempo, self.funcion)
-        pilas.mundo.agregar_tarea(1, self.restar_a_contador)
+        pilas.mundo.agregar_tarea_una_vez(self.tiempo, self.funcion)
+        pilas.mundo.agregar_tarea_siempre(1, self.restar_a_contador)
         
         
         
