@@ -18,10 +18,7 @@ class Escena:
     def iniciar(self):
         pass
 
-    def actualizar(self):
-        pass
-
-    def dibujar(self, aplicacion):
+    def terminar(self):
         pass
 
 
@@ -30,7 +27,4 @@ class Normal(Escena):
 
     def __init__(self, color_de_fondo=None):
         Escena.__init__(self)
-        self.fondo = color_de_fondo or pilas.colores.grisclaro
-
-    def dibujar(self, aplicacion):
-        pilas.motor.pintar(self.fondo)
+        self.fondo = pilas.fondos.Color(color_de_fondo)
